package main

import (
	"fmt"

	"github.com/BigJk/crt"
	bubbleadapter "github.com/BigJk/crt/bubbletea"
	"github.com/BigJk/crt/shader"
	tea "github.com/charmbracelet/bubbletea"
	"git.vertinext.com/roryejinn/Ultralight/ui"
	"git.vertinext.com/roryejinn/Ultralight/game"
)

type model struct {
	thisPlayer game.Player
	thisTheme ui.Rosepine
}

func (m model) Init() tea.Cmd {
	return nil
}

func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
	switch msg := msg.(type) {
	case tea.KeyMsg:
		switch msg.String() {
		case "ctrl+c":
			return m, tea.Quit
		case "up":
			m.thisPlayer.AdjustMoney(100)
		case "down":
			m.thisPlayer.AdjustMoney(-100)
		}
	}
	return m, nil
}

func (m model) View() string {
	return fmt.Sprintf("---\n\n%s has %d coins.\n\n---", m.thisPlayer.Name, m.thisPlayer.Money)
}

func main() {
	thisModel := model{
		thisPlayer: game.MakeNewPlayer("Alfonso"),
		thisTheme: ui.MakeTheme(),
	}

	fonts, err := crt.LoadFaces("assets/fonts/IosevkaTerm-Extended.ttf", "assets/fonts/IosevkaTerm-ExtendedBold.ttf", "assets/fonts/IosevkaTerm-ExtendedMedium.ttf", crt.GetFontDPI(), 16.0)
	if err != nil {
		panic(err)
	}

	win, _, err := bubbleadapter.Window(1000, 600, fonts, thisModel, thisModel.thisTheme.Base)
	if err != nil {
		panic(err)
	}

	lotte, err := shader.NewCrtBasic()
	if err != nil {
		panic(err)
	}

	win.SetShader(lotte)

	if err := win.Run("Simple"); err != nil {
		panic(err)
	}
}
